import click
from MOMORING.api.create_project import create_project_dir


@click.group()
def cmd1():
    pass


@cmd1.command()
@click.option('-p', '--project', default=None, help='Project name.')
def init(project):
    create_project_dir(project)


def run():
    cli = click.CommandCollection(sources=[cmd1])
    cli()



def nitrogen_utils():
    txt = '''\
import os
import shutil
import math


def get_path():
    datapath = os.environ.get('DATAPATH')
    savedpath = os.environ.get('SAVEDPATH')
    stashpath = os.environ.get('STASHPATH')
    return datapath, savedpath, stashpath
    

def get_cpu_num():
    """Get n_cpu, return NUM_CPU if user specified, else os.cpu_count()"""
    n_cpu = os.getenv('NUM_CPU')
    all_cpu = os.cpu_count()-1 if os.cpu_count() > 1 else 1

    if not n_cpu:
        n_cpu = all_cpu
    else:
        n_cpu = int(n_cpu)
        if n_cpu > all_cpu:
            n_cpu = all_cpu

    limit = os.getenv('CPU')
    if limit:
        n_cpu = math.ceil(int(limit)*2/3)

    print(f'n_cpu:{n_cpu}, limit:{limit}')
    return n_cpu


def create_workdir(dir_name='workdir'):
    stashpath = os.getenv('STASHPATH')
    if stashpath:
        # xbcp
        workdir = os.path.join(stashpath, dir_name)
    else:
        # local
        workdir = os.path.join('/home/', dir_name)

    if os.path.exists(workdir):
        shutil.rmtree(workdir)
    os.mkdir(workdir)
    return workdir


def get_env_param(env_str, default_value=None, type_func=str):
    value = os.getenv(env_str)
    if (value == True or value == False) and type_func == eval:
        return value
    if value:
        value = type_func(value)
    else:
        value = default_value
    print('ENV:', env_str, '| VALUE:', value, '| TYPE:', type(value))
    return value
'''
    return txt









import os


def create_python_package(package):
    if not os.path.exists(package):
        os.mkdir(package)
    f = open(os.path.join(package, '__init__.py'), 'w')
    f.close()


def create_dir(dir_name):
    if not os.path.exists(dir_name):
        os.mkdir(dir_name)


def create_file(file_name, txt=''):
    if not os.path.exists(file_name):
        f = open(file_name, 'w')
        f.write(txt)
        f.close()


